@@ -18,10 +18,8 @@
 #include <stdio.h>
 #include <popt.h>
 #include <glib.h>
-/* I know, that is is not nice, but that is exactly, what xml-config gives us */
-#include <parser.h>
-#include <xmlmemory.h>
-/* End of ugly thing */
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include <glib.h>
 #include <libgnomeprint/gnome-print-i18n.h>
 #include <libgnomeprint/gp-fontmap.h>
