@@ -37,7 +37,7 @@ typedef struct _GnomeFontClass GnomeFontClass;
 typedef struct _GnomeFontFamilyClass GnomeFontFamilyClass;
 typedef struct _GFFGlyphInfo GFFGlyphInfo;
 
-#include <gobject/gobject.h>
+#include <glib-object.h>
 #include <freetype/freetype.h>
 #include "gp-fontmap.h"
 #include "gnome-font.h"
