@@ -16,8 +16,8 @@
 #include <sys/stat.h>
 #include <stdlib.h>
 #include <string.h>
-#include <parser.h>
-#include <xmlmemory.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include "gp-fontmap.h"
 
 static GPFontMap * gp_fontmap_load (void);
